==> PlayerAnimationLibFabric-1.0.13%2Bmc.1.21.8-sources.jar: com/zigythebird/playeranim/animation/PlayerAnimManager.java <==
package com.zigythebird.playeranim.animation;

import com.zigythebird.playeranim.util.RenderUtil;
import com.zigythebird.playeranimcore.animation.layered.AnimationStack;
import com.zigythebird.playeranimcore.bones.PlayerAnimBone;
import net.minecraft.class_5603;
import net.minecraft.class_630;
import net.minecraft.class_742;
import org.jetbrains.annotations.ApiStatus;

/**
 * The animation data collection for a given player instance
 * <p>
 * Generally speaking, a single working-instance of a player will have a single instance of {@code PlayerAnimManager} associated with it
 */
public class PlayerAnimManager extends AnimationStack {
	private final class_742 player;

	private float lastUpdateTime;
	private boolean isFirstTick = true;
	private float tickDelta;

	public PlayerAnimManager(class_742 player) {
		this.player = player;
	}

	public float getLastUpdateTime() {
		return this.lastUpdateTime;
	}

	public void updatedAt(float updateTime) {
		this.lastUpdateTime = updateTime;
	}

	public boolean isFirstTick() {
		return this.isFirstTick;
	}

	protected void finishFirstTick() {
		this.isFirstTick = false;
	}

	public float getTickDelta() {
		return this.tickDelta;
	}

	/**
	 * If you touch this, you're a horrible person.
	 */
	@ApiStatus.Internal
	public void setTickDelta(float tickDelta) {
		this.tickDelta = tickDelta;
	}

	public class_742 getPlayer() {
		return player;
	}

	public void updatePart(class_630 part, PlayerAnimBone bone) {
		class_5603 initialPose = part.method_41921();
		bone = this.get3DTransform(bone);
		RenderUtil.translatePartToBone(part, bone, initialPose);
	}
}

==> PlayerAnimationLibFabric-1.1.3%2Bmc.1.21.1-sources.jar: com/zigythebird/playeranim/animation/PlayerAnimManager.java <==
package com.zigythebird.playeranim.animation;

import com.zigythebird.playeranim.util.RenderUtil;
import com.zigythebird.playeranimcore.animation.layered.AnimationStack;
import com.zigythebird.playeranimcore.bones.PlayerAnimBone;
import net.minecraft.class_5603;
import net.minecraft.class_630;
import net.minecraft.class_742;
import org.jetbrains.annotations.ApiStatus;

/**
 * The animation data collection for a given player instance
 * <p>
 * Generally speaking, a single working-instance of a player will have a single instance of {@code PlayerAnimManager} associated with it
 */
public class PlayerAnimManager extends AnimationStack {
	private final class_742 player;

	private float lastUpdateTime;
	private boolean isFirstTick = true;
	private float tickDelta;

	public PlayerAnimManager(class_742 player) {
		this.player = player;
	}

	public float getLastUpdateTime() {
		return this.lastUpdateTime;
	}

	public void updatedAt(float updateTime) {
		this.lastUpdateTime = updateTime;
	}

	public boolean isFirstTick() {
		return this.isFirstTick;
	}

	protected void finishFirstTick() {
		this.isFirstTick = false;
	}

	public float getTickDelta() {
		return this.tickDelta;
	}

	/**
	 * If you touch this, you're a horrible person.
	 */
	@ApiStatus.Internal
	public void setTickDelta(float tickDelta) {
		this.tickDelta = tickDelta;
	}

	public class_742 getPlayer() {
		return player;
	}

	public void updatePart(class_630 part, class_630 secondLayer, PlayerAnimBone bone) {
		class_5603 initialPose = part.method_41921();
		bone = this.get3DTransform(bone);
		RenderUtil.translatePartToBone(part, bone, initialPose);
		RenderUtil.translatePartToBone(secondLayer, bone, initialPose);
	}
}
